.. _configuring:

===========================
Neutron Configuration Guide
===========================

Configuration
-------------

.. toctree::
   :maxdepth: 1

   config
   config-samples

Policy
------

Neutron, like most OpenStack projects, uses a policy language to restrict
permissions on REST API actions.

.. toctree::
   :maxdepth: 1

   Policy Reference <policy>
   policy-sample
